# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MnqQueueArgs', 'MnqQueue']

@pulumi.input_type
class MnqQueueArgs:
    def __init__(__self__, *,
                 namespace_id: pulumi.Input[str],
                 message_max_age: Optional[pulumi.Input[int]] = None,
                 message_max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 nats: Optional[pulumi.Input['MnqQueueNatsArgs']] = None,
                 sqs: Optional[pulumi.Input['MnqQueueSqsArgs']] = None):
        """
        The set of arguments for constructing a MnqQueue resource.
        :param pulumi.Input[str] namespace_id: The ID of the Namespace associated to
        :param pulumi.Input[int] message_max_age: The number of seconds the queue retains a message.
        :param pulumi.Input[int] message_max_size: The maximum size of a message. Should be in bytes.
        :param pulumi.Input[str] name: The name of the queue. Conflicts with name_prefix.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with name.
        :param pulumi.Input['MnqQueueNatsArgs'] nats: The NATS attributes of the queue
        :param pulumi.Input['MnqQueueSqsArgs'] sqs: The SQS attributes of the queue
        """
        pulumi.set(__self__, "namespace_id", namespace_id)
        if message_max_age is not None:
            pulumi.set(__self__, "message_max_age", message_max_age)
        if message_max_size is not None:
            pulumi.set(__self__, "message_max_size", message_max_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if nats is not None:
            pulumi.set(__self__, "nats", nats)
        if sqs is not None:
            pulumi.set(__self__, "sqs", sqs)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Input[str]:
        """
        The ID of the Namespace associated to
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> Optional[pulumi.Input[int]]:
        """
        The number of seconds the queue retains a message.
        """
        return pulumi.get(self, "message_max_age")

    @message_max_age.setter
    def message_max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "message_max_age", value)

    @property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum size of a message. Should be in bytes.
        """
        return pulumi.get(self, "message_max_size")

    @message_max_size.setter
    def message_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "message_max_size", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the queue. Conflicts with name_prefix.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with name.
        """
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_prefix", value)

    @property
    @pulumi.getter
    def nats(self) -> Optional[pulumi.Input['MnqQueueNatsArgs']]:
        """
        The NATS attributes of the queue
        """
        return pulumi.get(self, "nats")

    @nats.setter
    def nats(self, value: Optional[pulumi.Input['MnqQueueNatsArgs']]):
        pulumi.set(self, "nats", value)

    @property
    @pulumi.getter
    def sqs(self) -> Optional[pulumi.Input['MnqQueueSqsArgs']]:
        """
        The SQS attributes of the queue
        """
        return pulumi.get(self, "sqs")

    @sqs.setter
    def sqs(self, value: Optional[pulumi.Input['MnqQueueSqsArgs']]):
        pulumi.set(self, "sqs", value)


@pulumi.input_type
class _MnqQueueState:
    def __init__(__self__, *,
                 message_max_age: Optional[pulumi.Input[int]] = None,
                 message_max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 nats: Optional[pulumi.Input['MnqQueueNatsArgs']] = None,
                 sqs: Optional[pulumi.Input['MnqQueueSqsArgs']] = None):
        """
        Input properties used for looking up and filtering MnqQueue resources.
        :param pulumi.Input[int] message_max_age: The number of seconds the queue retains a message.
        :param pulumi.Input[int] message_max_size: The maximum size of a message. Should be in bytes.
        :param pulumi.Input[str] name: The name of the queue. Conflicts with name_prefix.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with name.
        :param pulumi.Input[str] namespace_id: The ID of the Namespace associated to
        :param pulumi.Input['MnqQueueNatsArgs'] nats: The NATS attributes of the queue
        :param pulumi.Input['MnqQueueSqsArgs'] sqs: The SQS attributes of the queue
        """
        if message_max_age is not None:
            pulumi.set(__self__, "message_max_age", message_max_age)
        if message_max_size is not None:
            pulumi.set(__self__, "message_max_size", message_max_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if nats is not None:
            pulumi.set(__self__, "nats", nats)
        if sqs is not None:
            pulumi.set(__self__, "sqs", sqs)

    @property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> Optional[pulumi.Input[int]]:
        """
        The number of seconds the queue retains a message.
        """
        return pulumi.get(self, "message_max_age")

    @message_max_age.setter
    def message_max_age(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "message_max_age", value)

    @property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum size of a message. Should be in bytes.
        """
        return pulumi.get(self, "message_max_size")

    @message_max_size.setter
    def message_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "message_max_size", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the queue. Conflicts with name_prefix.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with name.
        """
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_prefix", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Namespace associated to
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter
    def nats(self) -> Optional[pulumi.Input['MnqQueueNatsArgs']]:
        """
        The NATS attributes of the queue
        """
        return pulumi.get(self, "nats")

    @nats.setter
    def nats(self, value: Optional[pulumi.Input['MnqQueueNatsArgs']]):
        pulumi.set(self, "nats", value)

    @property
    @pulumi.getter
    def sqs(self) -> Optional[pulumi.Input['MnqQueueSqsArgs']]:
        """
        The SQS attributes of the queue
        """
        return pulumi.get(self, "sqs")

    @sqs.setter
    def sqs(self, value: Optional[pulumi.Input['MnqQueueSqsArgs']]):
        pulumi.set(self, "sqs", value)


class MnqQueue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 message_max_age: Optional[pulumi.Input[int]] = None,
                 message_max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 nats: Optional[pulumi.Input[pulumi.InputType['MnqQueueNatsArgs']]] = None,
                 sqs: Optional[pulumi.Input[pulumi.InputType['MnqQueueSqsArgs']]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Messaging and Queuing queues.

        For more information about MNQ, see [the documentation](https://www.scaleway.com/en/developers/api/messaging-and-queuing/).

        > NOTE: This resource refers to the old version of the MNQ API. You should use new resources dedicated to your protocol. SQS.

        ## Examples

        ### NATS

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_mnq_namespace = scaleway.MnqNamespace("mainMnqNamespace", protocol="nats")
        main_mnq_credential = scaleway.MnqCredential("mainMnqCredential", namespace_id=main_mnq_namespace.id)
        my_queue = scaleway.MnqQueue("myQueue",
            namespace_id=main_mnq_namespace.id,
            nats=scaleway.MnqQueueNatsArgs(
                credentials=main_mnq_credential.nats_credentials.content,
            ))
        ```
        <!--End PulumiCodeChooser -->

        ### SQS

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_mnq_namespace = scaleway.MnqNamespace("mainMnqNamespace", protocol="sqs_sns")
        main_mnq_credential = scaleway.MnqCredential("mainMnqCredential",
            namespace_id=main_mnq_namespace.id,
            sqs_sns_credentials=scaleway.MnqCredentialSqsSnsCredentialsArgs(
                permissions=scaleway.MnqCredentialSqsSnsCredentialsPermissionsArgs(
                    can_publish=True,
                    can_receive=True,
                    can_manage=True,
                ),
            ))
        my_queue = scaleway.MnqQueue("myQueue",
            namespace_id=main_mnq_namespace.id,
            sqs=scaleway.MnqQueueSqsArgs(
                access_key=main_mnq_credential.sqs_sns_credentials.access_key,
                secret_key=main_mnq_credential.sqs_sns_credentials.secret_key,
            ))
        ```
        <!--End PulumiCodeChooser -->

        ### Argument Reference

        The following arguments are supported:

        * `namespace_id` - (Required) The ID of the Namespace associated to.

        * `name` - (Optional) The name of the queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.

        * `name_prefix` - (Optional) Creates a unique name beginning with the specified prefix. Conflicts with `name`.

        * `message_max_age` - (Optional) The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.

        * `message_max_size` - (Optional) The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.

        * `sqs` - (Optional) The SQS attributes of the queue. Conflicts with `nats`.
            - `endpoint` - (Optional) The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `http://sqs-sns.mnq.{region}.scw.cloud`.
            - `access_key` - (Required) The access key of the SQS queue.
            - `secret_key` - (Required) The secret key of the SQS queue.
            - `fifo_queue` - (Optional) Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
            - `content_based_deduplication` - (Optional) Specifies whether to enable content-based deduplication. Defaults to `false`.
            - `receive_wait_time_seconds` - (Optional) The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
            - `visibility_timeout_seconds` - (Optional) The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
            - For more information about the SQS limitations, see [the documentation](https://www.scaleway.com/en/developers/api/messaging-and-queuing/#technical-limitations).

        * `nats` - (Optional) The NATS attributes of the queue. Conflicts with `sqs`.
            - `endpoint` - (Optional) The endpoint of the NATS queue. Can contain a {region} placeholder. Defaults to `nats://nats.mnq.{region}.scw.cloud:4222`.
            - `credentials` - (Required) Line jump separated key and seed.
            - `retention_policy` - (Optional) The retention policy of the queue. See https://docs.nats.io/nats-concepts/jetstream/streams#retentionpolicy for more information. Defaults to `workqueue`.

        ### Attribute Reference

        In addition to all arguments above, the following attributes are exported:

        * `sqs` - The SQS attributes of the queue.
          ~ `url` - The URL of the queue.

        ### Import

        Queues can be imported using the `{region}/{namespace-id}/{queue-name}` format:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] message_max_age: The number of seconds the queue retains a message.
        :param pulumi.Input[int] message_max_size: The maximum size of a message. Should be in bytes.
        :param pulumi.Input[str] name: The name of the queue. Conflicts with name_prefix.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with name.
        :param pulumi.Input[str] namespace_id: The ID of the Namespace associated to
        :param pulumi.Input[pulumi.InputType['MnqQueueNatsArgs']] nats: The NATS attributes of the queue
        :param pulumi.Input[pulumi.InputType['MnqQueueSqsArgs']] sqs: The SQS attributes of the queue
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MnqQueueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Messaging and Queuing queues.

        For more information about MNQ, see [the documentation](https://www.scaleway.com/en/developers/api/messaging-and-queuing/).

        > NOTE: This resource refers to the old version of the MNQ API. You should use new resources dedicated to your protocol. SQS.

        ## Examples

        ### NATS

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_mnq_namespace = scaleway.MnqNamespace("mainMnqNamespace", protocol="nats")
        main_mnq_credential = scaleway.MnqCredential("mainMnqCredential", namespace_id=main_mnq_namespace.id)
        my_queue = scaleway.MnqQueue("myQueue",
            namespace_id=main_mnq_namespace.id,
            nats=scaleway.MnqQueueNatsArgs(
                credentials=main_mnq_credential.nats_credentials.content,
            ))
        ```
        <!--End PulumiCodeChooser -->

        ### SQS

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main_mnq_namespace = scaleway.MnqNamespace("mainMnqNamespace", protocol="sqs_sns")
        main_mnq_credential = scaleway.MnqCredential("mainMnqCredential",
            namespace_id=main_mnq_namespace.id,
            sqs_sns_credentials=scaleway.MnqCredentialSqsSnsCredentialsArgs(
                permissions=scaleway.MnqCredentialSqsSnsCredentialsPermissionsArgs(
                    can_publish=True,
                    can_receive=True,
                    can_manage=True,
                ),
            ))
        my_queue = scaleway.MnqQueue("myQueue",
            namespace_id=main_mnq_namespace.id,
            sqs=scaleway.MnqQueueSqsArgs(
                access_key=main_mnq_credential.sqs_sns_credentials.access_key,
                secret_key=main_mnq_credential.sqs_sns_credentials.secret_key,
            ))
        ```
        <!--End PulumiCodeChooser -->

        ### Argument Reference

        The following arguments are supported:

        * `namespace_id` - (Required) The ID of the Namespace associated to.

        * `name` - (Optional) The name of the queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.

        * `name_prefix` - (Optional) Creates a unique name beginning with the specified prefix. Conflicts with `name`.

        * `message_max_age` - (Optional) The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.

        * `message_max_size` - (Optional) The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.

        * `sqs` - (Optional) The SQS attributes of the queue. Conflicts with `nats`.
            - `endpoint` - (Optional) The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `http://sqs-sns.mnq.{region}.scw.cloud`.
            - `access_key` - (Required) The access key of the SQS queue.
            - `secret_key` - (Required) The secret key of the SQS queue.
            - `fifo_queue` - (Optional) Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
            - `content_based_deduplication` - (Optional) Specifies whether to enable content-based deduplication. Defaults to `false`.
            - `receive_wait_time_seconds` - (Optional) The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
            - `visibility_timeout_seconds` - (Optional) The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
            - For more information about the SQS limitations, see [the documentation](https://www.scaleway.com/en/developers/api/messaging-and-queuing/#technical-limitations).

        * `nats` - (Optional) The NATS attributes of the queue. Conflicts with `sqs`.
            - `endpoint` - (Optional) The endpoint of the NATS queue. Can contain a {region} placeholder. Defaults to `nats://nats.mnq.{region}.scw.cloud:4222`.
            - `credentials` - (Required) Line jump separated key and seed.
            - `retention_policy` - (Optional) The retention policy of the queue. See https://docs.nats.io/nats-concepts/jetstream/streams#retentionpolicy for more information. Defaults to `workqueue`.

        ### Attribute Reference

        In addition to all arguments above, the following attributes are exported:

        * `sqs` - The SQS attributes of the queue.
          ~ `url` - The URL of the queue.

        ### Import

        Queues can be imported using the `{region}/{namespace-id}/{queue-name}` format:

        :param str resource_name: The name of the resource.
        :param MnqQueueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MnqQueueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 message_max_age: Optional[pulumi.Input[int]] = None,
                 message_max_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_prefix: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 nats: Optional[pulumi.Input[pulumi.InputType['MnqQueueNatsArgs']]] = None,
                 sqs: Optional[pulumi.Input[pulumi.InputType['MnqQueueSqsArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MnqQueueArgs.__new__(MnqQueueArgs)

            __props__.__dict__["message_max_age"] = message_max_age
            __props__.__dict__["message_max_size"] = message_max_size
            __props__.__dict__["name"] = name
            __props__.__dict__["name_prefix"] = name_prefix
            if namespace_id is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_id'")
            __props__.__dict__["namespace_id"] = namespace_id
            __props__.__dict__["nats"] = nats
            __props__.__dict__["sqs"] = sqs
        super(MnqQueue, __self__).__init__(
            'scaleway:index/mnqQueue:MnqQueue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            message_max_age: Optional[pulumi.Input[int]] = None,
            message_max_size: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            name_prefix: Optional[pulumi.Input[str]] = None,
            namespace_id: Optional[pulumi.Input[str]] = None,
            nats: Optional[pulumi.Input[pulumi.InputType['MnqQueueNatsArgs']]] = None,
            sqs: Optional[pulumi.Input[pulumi.InputType['MnqQueueSqsArgs']]] = None) -> 'MnqQueue':
        """
        Get an existing MnqQueue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] message_max_age: The number of seconds the queue retains a message.
        :param pulumi.Input[int] message_max_size: The maximum size of a message. Should be in bytes.
        :param pulumi.Input[str] name: The name of the queue. Conflicts with name_prefix.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with name.
        :param pulumi.Input[str] namespace_id: The ID of the Namespace associated to
        :param pulumi.Input[pulumi.InputType['MnqQueueNatsArgs']] nats: The NATS attributes of the queue
        :param pulumi.Input[pulumi.InputType['MnqQueueSqsArgs']] sqs: The SQS attributes of the queue
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MnqQueueState.__new__(_MnqQueueState)

        __props__.__dict__["message_max_age"] = message_max_age
        __props__.__dict__["message_max_size"] = message_max_size
        __props__.__dict__["name"] = name
        __props__.__dict__["name_prefix"] = name_prefix
        __props__.__dict__["namespace_id"] = namespace_id
        __props__.__dict__["nats"] = nats
        __props__.__dict__["sqs"] = sqs
        return MnqQueue(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> pulumi.Output[Optional[int]]:
        """
        The number of seconds the queue retains a message.
        """
        return pulumi.get(self, "message_max_age")

    @property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum size of a message. Should be in bytes.
        """
        return pulumi.get(self, "message_max_size")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the queue. Conflicts with name_prefix.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> pulumi.Output[str]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with name.
        """
        return pulumi.get(self, "name_prefix")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Output[str]:
        """
        The ID of the Namespace associated to
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter
    def nats(self) -> pulumi.Output[Optional['outputs.MnqQueueNats']]:
        """
        The NATS attributes of the queue
        """
        return pulumi.get(self, "nats")

    @property
    @pulumi.getter
    def sqs(self) -> pulumi.Output[Optional['outputs.MnqQueueSqs']]:
        """
        The SQS attributes of the queue
        """
        return pulumi.get(self, "sqs")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubernetesNodePoolArgs', 'KubernetesNodePool']

@pulumi.input_type
class KubernetesNodePoolArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[str],
                 node_type: pulumi.Input[str],
                 size: pulumi.Input[int],
                 autohealing: Optional[pulumi.Input[bool]] = None,
                 autoscaling: Optional[pulumi.Input[bool]] = None,
                 container_runtime: Optional[pulumi.Input[str]] = None,
                 kubelet_args: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 min_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 placement_group_id: Optional[pulumi.Input[str]] = None,
                 public_ip_disabled: Optional[pulumi.Input[bool]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 root_volume_size_in_gb: Optional[pulumi.Input[int]] = None,
                 root_volume_type: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 upgrade_policy: Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']] = None,
                 wait_for_pool_ready: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a KubernetesNodePool resource.
        :param pulumi.Input[str] cluster_id: The ID of the Kubernetes cluster on which this pool will be created.
        :param pulumi.Input[str] node_type: The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.
               
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[int] size: The size of the pool.
               > **Important:** This field will only be used at creation if autoscaling is enabled.
        :param pulumi.Input[bool] autohealing: Enables the autohealing feature for this pool.
        :param pulumi.Input[bool] autoscaling: Enables the autoscaling feature for this pool.
               > **Important:** When enabled, an update of the `size` will not be taken into account.
        :param pulumi.Input[str] container_runtime: The container runtime of the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] kubelet_args: The Kubelet arguments to be used by this pool
        :param pulumi.Input[int] max_size: The maximum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[int] min_size: The minimum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[str] name: The name for the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] placement_group_id: The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[bool] public_ip_disabled: Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] region: `region`) The region in which the pool should be created.
        :param pulumi.Input[int] root_volume_size_in_gb: The size of the system volume of the nodes in gigabyte
        :param pulumi.Input[str] root_volume_type: System volume type of the nodes composing the pool
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags associated with the pool.
               > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        :param pulumi.Input['KubernetesNodePoolUpgradePolicyArgs'] upgrade_policy: The Pool upgrade policy
        :param pulumi.Input[bool] wait_for_pool_ready: Whether to wait for the pool to be ready.
        :param pulumi.Input[str] zone: `zone`) The zone in which the pool should be created.
               > **Important:** Updates to this field will recreate a new resource.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "node_type", node_type)
        pulumi.set(__self__, "size", size)
        if autohealing is not None:
            pulumi.set(__self__, "autohealing", autohealing)
        if autoscaling is not None:
            pulumi.set(__self__, "autoscaling", autoscaling)
        if container_runtime is not None:
            pulumi.set(__self__, "container_runtime", container_runtime)
        if kubelet_args is not None:
            pulumi.set(__self__, "kubelet_args", kubelet_args)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if min_size is not None:
            pulumi.set(__self__, "min_size", min_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if placement_group_id is not None:
            pulumi.set(__self__, "placement_group_id", placement_group_id)
        if public_ip_disabled is not None:
            pulumi.set(__self__, "public_ip_disabled", public_ip_disabled)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if root_volume_size_in_gb is not None:
            pulumi.set(__self__, "root_volume_size_in_gb", root_volume_size_in_gb)
        if root_volume_type is not None:
            pulumi.set(__self__, "root_volume_type", root_volume_type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if upgrade_policy is not None:
            pulumi.set(__self__, "upgrade_policy", upgrade_policy)
        if wait_for_pool_ready is not None:
            pulumi.set(__self__, "wait_for_pool_ready", wait_for_pool_ready)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[str]:
        """
        The ID of the Kubernetes cluster on which this pool will be created.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Input[str]:
        """
        The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.

        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "node_type", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        """
        The size of the pool.
        > **Important:** This field will only be used at creation if autoscaling is enabled.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def autohealing(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables the autohealing feature for this pool.
        """
        return pulumi.get(self, "autohealing")

    @autohealing.setter
    def autohealing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autohealing", value)

    @property
    @pulumi.getter
    def autoscaling(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables the autoscaling feature for this pool.
        > **Important:** When enabled, an update of the `size` will not be taken into account.
        """
        return pulumi.get(self, "autoscaling")

    @autoscaling.setter
    def autoscaling(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autoscaling", value)

    @property
    @pulumi.getter(name="containerRuntime")
    def container_runtime(self) -> Optional[pulumi.Input[str]]:
        """
        The container runtime of the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "container_runtime")

    @container_runtime.setter
    def container_runtime(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_runtime", value)

    @property
    @pulumi.getter(name="kubeletArgs")
    def kubelet_args(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The Kubelet arguments to be used by this pool
        """
        return pulumi.get(self, "kubelet_args")

    @kubelet_args.setter
    def kubelet_args(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "kubelet_args", value)

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_size", value)

    @property
    @pulumi.getter(name="minSize")
    def min_size(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "min_size")

    @min_size.setter
    def min_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_size", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="placementGroupId")
    def placement_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "placement_group_id")

    @placement_group_id.setter
    def placement_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_group_id", value)

    @property
    @pulumi.getter(name="publicIpDisabled")
    def public_ip_disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "public_ip_disabled")

    @public_ip_disabled.setter
    def public_ip_disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "public_ip_disabled", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        `region`) The region in which the pool should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="rootVolumeSizeInGb")
    def root_volume_size_in_gb(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the system volume of the nodes in gigabyte
        """
        return pulumi.get(self, "root_volume_size_in_gb")

    @root_volume_size_in_gb.setter
    def root_volume_size_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "root_volume_size_in_gb", value)

    @property
    @pulumi.getter(name="rootVolumeType")
    def root_volume_type(self) -> Optional[pulumi.Input[str]]:
        """
        System volume type of the nodes composing the pool
        """
        return pulumi.get(self, "root_volume_type")

    @root_volume_type.setter
    def root_volume_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_volume_type", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The tags associated with the pool.
        > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="upgradePolicy")
    def upgrade_policy(self) -> Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']]:
        """
        The Pool upgrade policy
        """
        return pulumi.get(self, "upgrade_policy")

    @upgrade_policy.setter
    def upgrade_policy(self, value: Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']]):
        pulumi.set(self, "upgrade_policy", value)

    @property
    @pulumi.getter(name="waitForPoolReady")
    def wait_for_pool_ready(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to wait for the pool to be ready.
        """
        return pulumi.get(self, "wait_for_pool_ready")

    @wait_for_pool_ready.setter
    def wait_for_pool_ready(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wait_for_pool_ready", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        `zone`) The zone in which the pool should be created.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _KubernetesNodePoolState:
    def __init__(__self__, *,
                 autohealing: Optional[pulumi.Input[bool]] = None,
                 autoscaling: Optional[pulumi.Input[bool]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_runtime: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 current_size: Optional[pulumi.Input[int]] = None,
                 kubelet_args: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 min_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_type: Optional[pulumi.Input[str]] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesNodePoolNodeArgs']]]] = None,
                 placement_group_id: Optional[pulumi.Input[str]] = None,
                 public_ip_disabled: Optional[pulumi.Input[bool]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 root_volume_size_in_gb: Optional[pulumi.Input[int]] = None,
                 root_volume_type: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 upgrade_policy: Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 wait_for_pool_ready: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering KubernetesNodePool resources.
        :param pulumi.Input[bool] autohealing: Enables the autohealing feature for this pool.
        :param pulumi.Input[bool] autoscaling: Enables the autoscaling feature for this pool.
               > **Important:** When enabled, an update of the `size` will not be taken into account.
        :param pulumi.Input[str] cluster_id: The ID of the Kubernetes cluster on which this pool will be created.
        :param pulumi.Input[str] container_runtime: The container runtime of the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] created_at: The creation date of the pool.
        :param pulumi.Input[int] current_size: The actual size of the pool
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] kubelet_args: The Kubelet arguments to be used by this pool
        :param pulumi.Input[int] max_size: The maximum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[int] min_size: The minimum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[str] name: The name for the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] node_type: The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.
               
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[Sequence[pulumi.Input['KubernetesNodePoolNodeArgs']]] nodes: (List of) The nodes in the default pool.
        :param pulumi.Input[str] placement_group_id: The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[bool] public_ip_disabled: Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] region: `region`) The region in which the pool should be created.
        :param pulumi.Input[int] root_volume_size_in_gb: The size of the system volume of the nodes in gigabyte
        :param pulumi.Input[str] root_volume_type: System volume type of the nodes composing the pool
        :param pulumi.Input[int] size: The size of the pool.
               > **Important:** This field will only be used at creation if autoscaling is enabled.
        :param pulumi.Input[str] status: The status of the node.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags associated with the pool.
               > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        :param pulumi.Input[str] updated_at: The last update date of the pool.
        :param pulumi.Input['KubernetesNodePoolUpgradePolicyArgs'] upgrade_policy: The Pool upgrade policy
        :param pulumi.Input[str] version: The version of the pool.
        :param pulumi.Input[bool] wait_for_pool_ready: Whether to wait for the pool to be ready.
        :param pulumi.Input[str] zone: `zone`) The zone in which the pool should be created.
               > **Important:** Updates to this field will recreate a new resource.
        """
        if autohealing is not None:
            pulumi.set(__self__, "autohealing", autohealing)
        if autoscaling is not None:
            pulumi.set(__self__, "autoscaling", autoscaling)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if container_runtime is not None:
            pulumi.set(__self__, "container_runtime", container_runtime)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_size is not None:
            pulumi.set(__self__, "current_size", current_size)
        if kubelet_args is not None:
            pulumi.set(__self__, "kubelet_args", kubelet_args)
        if max_size is not None:
            pulumi.set(__self__, "max_size", max_size)
        if min_size is not None:
            pulumi.set(__self__, "min_size", min_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_type is not None:
            pulumi.set(__self__, "node_type", node_type)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if placement_group_id is not None:
            pulumi.set(__self__, "placement_group_id", placement_group_id)
        if public_ip_disabled is not None:
            pulumi.set(__self__, "public_ip_disabled", public_ip_disabled)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if root_volume_size_in_gb is not None:
            pulumi.set(__self__, "root_volume_size_in_gb", root_volume_size_in_gb)
        if root_volume_type is not None:
            pulumi.set(__self__, "root_volume_type", root_volume_type)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if upgrade_policy is not None:
            pulumi.set(__self__, "upgrade_policy", upgrade_policy)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if wait_for_pool_ready is not None:
            pulumi.set(__self__, "wait_for_pool_ready", wait_for_pool_ready)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def autohealing(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables the autohealing feature for this pool.
        """
        return pulumi.get(self, "autohealing")

    @autohealing.setter
    def autohealing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autohealing", value)

    @property
    @pulumi.getter
    def autoscaling(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables the autoscaling feature for this pool.
        > **Important:** When enabled, an update of the `size` will not be taken into account.
        """
        return pulumi.get(self, "autoscaling")

    @autoscaling.setter
    def autoscaling(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autoscaling", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Kubernetes cluster on which this pool will be created.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="containerRuntime")
    def container_runtime(self) -> Optional[pulumi.Input[str]]:
        """
        The container runtime of the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "container_runtime")

    @container_runtime.setter
    def container_runtime(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_runtime", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The creation date of the pool.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> Optional[pulumi.Input[int]]:
        """
        The actual size of the pool
        """
        return pulumi.get(self, "current_size")

    @current_size.setter
    def current_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "current_size", value)

    @property
    @pulumi.getter(name="kubeletArgs")
    def kubelet_args(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The Kubelet arguments to be used by this pool
        """
        return pulumi.get(self, "kubelet_args")

    @kubelet_args.setter
    def kubelet_args(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "kubelet_args", value)

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "max_size")

    @max_size.setter
    def max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_size", value)

    @property
    @pulumi.getter(name="minSize")
    def min_size(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "min_size")

    @min_size.setter
    def min_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_size", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[pulumi.Input[str]]:
        """
        The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.

        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_type", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesNodePoolNodeArgs']]]]:
        """
        (List of) The nodes in the default pool.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubernetesNodePoolNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="placementGroupId")
    def placement_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "placement_group_id")

    @placement_group_id.setter
    def placement_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_group_id", value)

    @property
    @pulumi.getter(name="publicIpDisabled")
    def public_ip_disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "public_ip_disabled")

    @public_ip_disabled.setter
    def public_ip_disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "public_ip_disabled", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        `region`) The region in which the pool should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="rootVolumeSizeInGb")
    def root_volume_size_in_gb(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the system volume of the nodes in gigabyte
        """
        return pulumi.get(self, "root_volume_size_in_gb")

    @root_volume_size_in_gb.setter
    def root_volume_size_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "root_volume_size_in_gb", value)

    @property
    @pulumi.getter(name="rootVolumeType")
    def root_volume_type(self) -> Optional[pulumi.Input[str]]:
        """
        System volume type of the nodes composing the pool
        """
        return pulumi.get(self, "root_volume_type")

    @root_volume_type.setter
    def root_volume_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_volume_type", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the pool.
        > **Important:** This field will only be used at creation if autoscaling is enabled.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the node.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The tags associated with the pool.
        > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        The last update date of the pool.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="upgradePolicy")
    def upgrade_policy(self) -> Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']]:
        """
        The Pool upgrade policy
        """
        return pulumi.get(self, "upgrade_policy")

    @upgrade_policy.setter
    def upgrade_policy(self, value: Optional[pulumi.Input['KubernetesNodePoolUpgradePolicyArgs']]):
        pulumi.set(self, "upgrade_policy", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the pool.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="waitForPoolReady")
    def wait_for_pool_ready(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to wait for the pool to be ready.
        """
        return pulumi.get(self, "wait_for_pool_ready")

    @wait_for_pool_ready.setter
    def wait_for_pool_ready(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wait_for_pool_ready", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        `zone`) The zone in which the pool should be created.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


class KubernetesNodePool(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 autohealing: Optional[pulumi.Input[bool]] = None,
                 autoscaling: Optional[pulumi.Input[bool]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_runtime: Optional[pulumi.Input[str]] = None,
                 kubelet_args: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 min_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_type: Optional[pulumi.Input[str]] = None,
                 placement_group_id: Optional[pulumi.Input[str]] = None,
                 public_ip_disabled: Optional[pulumi.Input[bool]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 root_volume_size_in_gb: Optional[pulumi.Input[int]] = None,
                 root_volume_type: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 upgrade_policy: Optional[pulumi.Input[pulumi.InputType['KubernetesNodePoolUpgradePolicyArgs']]] = None,
                 wait_for_pool_ready: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        Kubernetes pools can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/kubernetesNodePool:KubernetesNodePool mypool fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] autohealing: Enables the autohealing feature for this pool.
        :param pulumi.Input[bool] autoscaling: Enables the autoscaling feature for this pool.
               > **Important:** When enabled, an update of the `size` will not be taken into account.
        :param pulumi.Input[str] cluster_id: The ID of the Kubernetes cluster on which this pool will be created.
        :param pulumi.Input[str] container_runtime: The container runtime of the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] kubelet_args: The Kubelet arguments to be used by this pool
        :param pulumi.Input[int] max_size: The maximum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[int] min_size: The minimum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[str] name: The name for the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] node_type: The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.
               
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] placement_group_id: The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[bool] public_ip_disabled: Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] region: `region`) The region in which the pool should be created.
        :param pulumi.Input[int] root_volume_size_in_gb: The size of the system volume of the nodes in gigabyte
        :param pulumi.Input[str] root_volume_type: System volume type of the nodes composing the pool
        :param pulumi.Input[int] size: The size of the pool.
               > **Important:** This field will only be used at creation if autoscaling is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags associated with the pool.
               > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        :param pulumi.Input[pulumi.InputType['KubernetesNodePoolUpgradePolicyArgs']] upgrade_policy: The Pool upgrade policy
        :param pulumi.Input[bool] wait_for_pool_ready: Whether to wait for the pool to be ready.
        :param pulumi.Input[str] zone: `zone`) The zone in which the pool should be created.
               > **Important:** Updates to this field will recreate a new resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubernetesNodePoolArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Kubernetes pools can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/kubernetesNodePool:KubernetesNodePool mypool fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param KubernetesNodePoolArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubernetesNodePoolArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 autohealing: Optional[pulumi.Input[bool]] = None,
                 autoscaling: Optional[pulumi.Input[bool]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 container_runtime: Optional[pulumi.Input[str]] = None,
                 kubelet_args: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 max_size: Optional[pulumi.Input[int]] = None,
                 min_size: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_type: Optional[pulumi.Input[str]] = None,
                 placement_group_id: Optional[pulumi.Input[str]] = None,
                 public_ip_disabled: Optional[pulumi.Input[bool]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 root_volume_size_in_gb: Optional[pulumi.Input[int]] = None,
                 root_volume_type: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 upgrade_policy: Optional[pulumi.Input[pulumi.InputType['KubernetesNodePoolUpgradePolicyArgs']]] = None,
                 wait_for_pool_ready: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubernetesNodePoolArgs.__new__(KubernetesNodePoolArgs)

            __props__.__dict__["autohealing"] = autohealing
            __props__.__dict__["autoscaling"] = autoscaling
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["container_runtime"] = container_runtime
            __props__.__dict__["kubelet_args"] = kubelet_args
            __props__.__dict__["max_size"] = max_size
            __props__.__dict__["min_size"] = min_size
            __props__.__dict__["name"] = name
            if node_type is None and not opts.urn:
                raise TypeError("Missing required property 'node_type'")
            __props__.__dict__["node_type"] = node_type
            __props__.__dict__["placement_group_id"] = placement_group_id
            __props__.__dict__["public_ip_disabled"] = public_ip_disabled
            __props__.__dict__["region"] = region
            __props__.__dict__["root_volume_size_in_gb"] = root_volume_size_in_gb
            __props__.__dict__["root_volume_type"] = root_volume_type
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["tags"] = tags
            __props__.__dict__["upgrade_policy"] = upgrade_policy
            __props__.__dict__["wait_for_pool_ready"] = wait_for_pool_ready
            __props__.__dict__["zone"] = zone
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_size"] = None
            __props__.__dict__["nodes"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["version"] = None
        super(KubernetesNodePool, __self__).__init__(
            'scaleway:index/kubernetesNodePool:KubernetesNodePool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            autohealing: Optional[pulumi.Input[bool]] = None,
            autoscaling: Optional[pulumi.Input[bool]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            container_runtime: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            current_size: Optional[pulumi.Input[int]] = None,
            kubelet_args: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            max_size: Optional[pulumi.Input[int]] = None,
            min_size: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            node_type: Optional[pulumi.Input[str]] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['KubernetesNodePoolNodeArgs']]]]] = None,
            placement_group_id: Optional[pulumi.Input[str]] = None,
            public_ip_disabled: Optional[pulumi.Input[bool]] = None,
            region: Optional[pulumi.Input[str]] = None,
            root_volume_size_in_gb: Optional[pulumi.Input[int]] = None,
            root_volume_type: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            upgrade_policy: Optional[pulumi.Input[pulumi.InputType['KubernetesNodePoolUpgradePolicyArgs']]] = None,
            version: Optional[pulumi.Input[str]] = None,
            wait_for_pool_ready: Optional[pulumi.Input[bool]] = None,
            zone: Optional[pulumi.Input[str]] = None) -> 'KubernetesNodePool':
        """
        Get an existing KubernetesNodePool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] autohealing: Enables the autohealing feature for this pool.
        :param pulumi.Input[bool] autoscaling: Enables the autoscaling feature for this pool.
               > **Important:** When enabled, an update of the `size` will not be taken into account.
        :param pulumi.Input[str] cluster_id: The ID of the Kubernetes cluster on which this pool will be created.
        :param pulumi.Input[str] container_runtime: The container runtime of the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] created_at: The creation date of the pool.
        :param pulumi.Input[int] current_size: The actual size of the pool
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] kubelet_args: The Kubelet arguments to be used by this pool
        :param pulumi.Input[int] max_size: The maximum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[int] min_size: The minimum size of the pool, used by the autoscaling feature.
        :param pulumi.Input[str] name: The name for the pool.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] node_type: The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.
               
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['KubernetesNodePoolNodeArgs']]]] nodes: (List of) The nodes in the default pool.
        :param pulumi.Input[str] placement_group_id: The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[bool] public_ip_disabled: Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
               > **Important:** Updates to this field will recreate a new resource.
        :param pulumi.Input[str] region: `region`) The region in which the pool should be created.
        :param pulumi.Input[int] root_volume_size_in_gb: The size of the system volume of the nodes in gigabyte
        :param pulumi.Input[str] root_volume_type: System volume type of the nodes composing the pool
        :param pulumi.Input[int] size: The size of the pool.
               > **Important:** This field will only be used at creation if autoscaling is enabled.
        :param pulumi.Input[str] status: The status of the node.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags associated with the pool.
               > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        :param pulumi.Input[str] updated_at: The last update date of the pool.
        :param pulumi.Input[pulumi.InputType['KubernetesNodePoolUpgradePolicyArgs']] upgrade_policy: The Pool upgrade policy
        :param pulumi.Input[str] version: The version of the pool.
        :param pulumi.Input[bool] wait_for_pool_ready: Whether to wait for the pool to be ready.
        :param pulumi.Input[str] zone: `zone`) The zone in which the pool should be created.
               > **Important:** Updates to this field will recreate a new resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubernetesNodePoolState.__new__(_KubernetesNodePoolState)

        __props__.__dict__["autohealing"] = autohealing
        __props__.__dict__["autoscaling"] = autoscaling
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["container_runtime"] = container_runtime
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_size"] = current_size
        __props__.__dict__["kubelet_args"] = kubelet_args
        __props__.__dict__["max_size"] = max_size
        __props__.__dict__["min_size"] = min_size
        __props__.__dict__["name"] = name
        __props__.__dict__["node_type"] = node_type
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["placement_group_id"] = placement_group_id
        __props__.__dict__["public_ip_disabled"] = public_ip_disabled
        __props__.__dict__["region"] = region
        __props__.__dict__["root_volume_size_in_gb"] = root_volume_size_in_gb
        __props__.__dict__["root_volume_type"] = root_volume_type
        __props__.__dict__["size"] = size
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["upgrade_policy"] = upgrade_policy
        __props__.__dict__["version"] = version
        __props__.__dict__["wait_for_pool_ready"] = wait_for_pool_ready
        __props__.__dict__["zone"] = zone
        return KubernetesNodePool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def autohealing(self) -> pulumi.Output[Optional[bool]]:
        """
        Enables the autohealing feature for this pool.
        """
        return pulumi.get(self, "autohealing")

    @property
    @pulumi.getter
    def autoscaling(self) -> pulumi.Output[Optional[bool]]:
        """
        Enables the autoscaling feature for this pool.
        > **Important:** When enabled, an update of the `size` will not be taken into account.
        """
        return pulumi.get(self, "autoscaling")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        The ID of the Kubernetes cluster on which this pool will be created.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="containerRuntime")
    def container_runtime(self) -> pulumi.Output[Optional[str]]:
        """
        The container runtime of the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "container_runtime")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The creation date of the pool.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> pulumi.Output[int]:
        """
        The actual size of the pool
        """
        return pulumi.get(self, "current_size")

    @property
    @pulumi.getter(name="kubeletArgs")
    def kubelet_args(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The Kubelet arguments to be used by this pool
        """
        return pulumi.get(self, "kubelet_args")

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> pulumi.Output[int]:
        """
        The maximum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "max_size")

    @property
    @pulumi.getter(name="minSize")
    def min_size(self) -> pulumi.Output[Optional[int]]:
        """
        The minimum size of the pool, used by the autoscaling feature.
        """
        return pulumi.get(self, "min_size")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for the pool.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Output[str]:
        """
        The commercial type of the pool instances. Instances with insufficient memory are not eligible (DEV1-S, PLAY2-PICO, STARDUST). `external` is a special node type used to provision from other Cloud providers.

        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "node_type")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Sequence['outputs.KubernetesNodePoolNode']]:
        """
        (List of) The nodes in the default pool.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="placementGroupId")
    def placement_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The [placement group](https://www.scaleway.com/en/developers/api/instance/#placement-groups-d8f653) the nodes of the pool will be attached to.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "placement_group_id")

    @property
    @pulumi.getter(name="publicIpDisabled")
    def public_ip_disabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Defines if the public IP should be removed from Nodes. To use this feature, your Cluster must have an attached Private Network set up with a Public Gateway.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "public_ip_disabled")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        `region`) The region in which the pool should be created.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="rootVolumeSizeInGb")
    def root_volume_size_in_gb(self) -> pulumi.Output[int]:
        """
        The size of the system volume of the nodes in gigabyte
        """
        return pulumi.get(self, "root_volume_size_in_gb")

    @property
    @pulumi.getter(name="rootVolumeType")
    def root_volume_type(self) -> pulumi.Output[str]:
        """
        System volume type of the nodes composing the pool
        """
        return pulumi.get(self, "root_volume_type")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[int]:
        """
        The size of the pool.
        > **Important:** This field will only be used at creation if autoscaling is enabled.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the node.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The tags associated with the pool.
        > Note: As mentionned in [this document](https://github.com/scaleway/scaleway-cloud-controller-manager/blob/master/docs/tags.md#taints), taints of a pool's nodes are applied using tags. (Example: "taint=taintName=taineValue:Effect")
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        The last update date of the pool.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="upgradePolicy")
    def upgrade_policy(self) -> pulumi.Output['outputs.KubernetesNodePoolUpgradePolicy']:
        """
        The Pool upgrade policy
        """
        return pulumi.get(self, "upgrade_policy")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[str]:
        """
        The version of the pool.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="waitForPoolReady")
    def wait_for_pool_ready(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to wait for the pool to be ready.
        """
        return pulumi.get(self, "wait_for_pool_ready")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[str]:
        """
        `zone`) The zone in which the pool should be created.
        > **Important:** Updates to this field will recreate a new resource.
        """
        return pulumi.get(self, "zone")

